# Protobuf messages in messages_pb2 are tracked by git, so when importing this repo as submodule # there is no need to compile protobuf.

If you are reading this outside of PyPi, this project is published:
```pip install advance-common```